======================
Introduction to Python
======================

This section provides a basic introduction to the Python programming language. You are encouraged to try the examples and to experiment with Python statements.

The Python language is used throughout Abaqus, not only in the Abaqus Scripting Interface. Python is also used by Abaqus/Design to perform parametric studies and in the Abaqus/Standard, Abaqus/Explicit, and Abaqus/CAE environment file. For more information, see `Parametric Studies <https://help.3ds.com/2021/english/dssimulia_established/SIMACAEANLRefMap/simaanl-m-ParametricStudies-sb.htm?contextscope=all>`_ and `Environment File Settings <https://help.3ds.com/2021/english/dssimulia_established/SIMACAEEXCRefMap/simaexc-c-envfile.htm?contextscope=all>`_.

.. toctree::
   :maxdepth: 1
   :caption: Contents

   introduction/python-abaqus
   introduction/python-resources
   introduction/python-interpreter
   introduction/oop-basics
   introduction/python-basics
   introduction/programming
   introduction/further-reading